==> billogram-foundation-3.0.3.tgz: package/modules/components/textarea/Textarea.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../isNullOrEmpty';

export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            height: PropTypes.number,
            maxLength: PropTypes.string,
            onChange: PropTypes.func,
            placeholder: PropTypes.string,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                onChange: (/* value */) => {},
                placeholder: '',
                value: ''
            };
        },

        componentDidMount() {
            this.focus();
        },

        componentDidUpdate() {
            this.focus();
        },

        onChange(evt) {
            this.props.onChange(evt.target.value);
        },

        focus() {
            if (this.props.focus) {
                this.textarea.focus();
                this.textarea.select();
            }
        },

        render() {
            const { disabled, error, height, maxLength, placeholder, value } = this.props;
            return (
                <textarea
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    onChange={ this.onChange }
                    placeholder={ placeholder }
                    ref={ (c) => this.textarea = c }
                    style={ { height } }
                    value={ value } />
            );
        }

    });

};

==> billogram-foundation-3.7.0.tgz: package/modules/components/textarea/Textarea.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import invariant from 'invariant';

import isNullOrEmpty from '../../isNullOrEmpty';

export default ({
    block,
    displayName
} = {}) => {

    invariant(block !== undefined, 'Missing purebem block.');
    invariant(!isNullOrEmpty(displayName), 'Missing display name.');

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            error: PropTypes.bool,
            focus: PropTypes.bool,
            height: PropTypes.number,
            maxLength: PropTypes.number,
            onChange: PropTypes.func,
            placeholder: PropTypes.string,
            value: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                error: false,
                focus: false,
                onChange: (/* value */) => {},
                placeholder: '',
                value: ''
            };
        },

        componentDidMount() {
            this.focus();
        },

        onChange(evt) {
            this.props.onChange(evt.target.value);
        },

        focus() {
            if (this.props.focus) {
                this.textarea.focus();
                this.textarea.select();
            }
        },

        render() {
            const { disabled, error, height, maxLength, placeholder, value } = this.props;
            return (
                <textarea
                    className={ block({ disabled, error }) }
                    disabled={ disabled }
                    maxLength={ maxLength }
                    onChange={ this.onChange }
                    placeholder={ placeholder }
                    ref={ (c) => this.textarea = c }
                    style={ { height } }
                    value={ value } />
            );
        }

    });

};
